.. include:: ../definitions.txt

.. _tutorial:

The ProcGraph tutorial
======================

Welcome to the |procgraph| tutorial!
This tutorial will guide you through the first steps with |procgraph|, from the basic syntax,
up to the recommended design patterns and how to document your creations.

Even though it is fine to read this on the web, cutting&paste the examples to your terminal or editor, it is advised that you download the |procgraph| source code. There, in the directory
``docs/tutorial``, you will find all these scripts and resources in separate files ready to run.

.. include:: tutorial00.txt
.. include:: tutorial01.txt
.. include:: tutorial02.txt
.. include:: tutorial03.txt
.. include:: tutorial04.txt
.. include:: tutorial05.txt
.. include:: tutorial06.txt
.. include:: tutorial07.txt
.. include:: tutorial08.txt
.. include:: tutorial09.txt
.. include:: tutorial10.txt
